require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_website',
  dscmeta_resource_friendly_name: 'Website',
  dscmeta_resource_name: 'ChefConf_Website',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'ChefConfSamples',
  dscmeta_module_version: '0.9.0',
  docs: 'The DSC Website resource type.
         Automatically generated from version 0.9.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_physicalpath: {
      type: 'String',
      desc: ' ',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_id: {
      type: 'Optional[String]',
      desc: ' ',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_applicationpool: {
      type: 'Optional[String]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_state: {
      type: "Optional[Enum['Started', 'Stopped']]",
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: 'String',
      desc: ' ',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_webconfigprop: {
      type: 'Optional[Array[Struct[{
              filter => Optional[String],
              value => Optional[String],
              pspath => Optional[String],
              name => Optional[String],
              location => Optional[String]
            }]]]',
      desc: 'Hashtable containing Web Configuration Properties (Filter, PSPath, Name, Location, Value)',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'ChefConf_WebConfigProp[]',
      mof_is_embedded: true,
    },
  },
)
